@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function
-
 from .._internal.axis_transform import (
     AxisTransform,
     Function,
@@ -8,8 +5,6 @@ from .._internal.axis_transform import (
     _internal_conversion,
 )
 
-del absolute_import, division, print_function
-
 __all__ = ("AxisTransform", "Pow", "Function", "sqrt", "log")
 
 sqrt = Function("_sqrt_fn", "_sq_fn", convert=_internal_conversion, name="sqrt")
